.. AUTO-GENERATED FILE -- DO NOT EDIT!

torch
=====

Module: :mod:`torch`
--------------------
.. automodule:: ISLP.torch

.. currentmodule:: ISLP.torch

.. autofunction:: ISLP.torch.rec_num_workers

